/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.text;

import it.tidalwave.metadata.text.ApertureFormat.F;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class ApertureFormatTest 
  {
    private ApertureFormat format;
    private ApertureFormat formatUnicode;
    
    @Before
    public void setupFixture()
      {
        format = new ApertureFormat();
        formatUnicode = new ApertureFormat(F.UNICODE);
      }  

    @After
    public void tearDownFixture() 
      {
        format = null;
      }

    @Test
    public void testFormat() 
      {
        assertEquals("f/0", format.format(0.0));
        assertEquals("f/1", format.format(1.0));
        assertEquals("f/2.8", format.format(2.8));
        assertEquals("f/4", format.format(4.0));
        assertEquals("f/5.6", format.format(5.6));
        assertEquals("f/11", format.format(11.0));
        assertEquals("f/16", format.format(16.0));
        assertEquals("f/22", format.format(22.0));
        assertEquals("f/32", format.format(32.0));
      }

    @Test
    public void testFormatUnicode() 
      {
        assertEquals("\u0192/0", formatUnicode.format(0.0));
        assertEquals("\u0192/1", formatUnicode.format(1.0));
        assertEquals("\u0192/2.8", formatUnicode.format(2.8));
        assertEquals("\u0192/4", formatUnicode.format(4.0));
        assertEquals("\u0192/5.6", formatUnicode.format(5.6));
        assertEquals("\u0192/11", formatUnicode.format(11.0));
        assertEquals("\u0192/16", formatUnicode.format(16.0));
        assertEquals("\u0192/22", formatUnicode.format(22.0));
        assertEquals("\u0192/32", formatUnicode.format(32.0));
      }

    @Test
    public void testParse() 
      {
        assertEquals(0.0, format.parse("f/0"));
        assertEquals(1.0, format.parse("f/1"));
        assertEquals(2.8, format.parse("f/2.8"));
        assertEquals(4.0, format.parse("f/4"));
        assertEquals(5.6, format.parse("f/5.6"));
        assertEquals(11.0, format.parse("f/11"));
        assertEquals(16.0, format.parse("f/16"));
        assertEquals(22.0, format.parse("f/22"));
        assertEquals(32.0, format.parse("f/32"));
      }
  }