/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.text;

import java.text.ParseException;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class EVFormatTest 
  {
    private EVFormat format;
    private EVFormat formatUnicode;
    
    @Before
    public void setupFixture()
      {
        format = new EVFormat();
        formatUnicode = new EVFormat(EVFormat.Fractions.UNICODE);
      }  

    @After
    public void tearDownFixture() 
      {
        format = null;
      }

    @Test
    public void testFormat() 
      {
        assertEquals("-1 5/6 EV", format.format(-1 - 5/6.0));
        assertEquals("-1 2/3 EV", format.format(-1 - 2/3.0));
        assertEquals("-1 1/2 EV", format.format(-1 - 1/2.0));
        assertEquals("-1 1/3 EV", format.format(-1 - 1/3.0));
        assertEquals("-1 1/6 EV", format.format(-1 - 1/6.0));
        assertEquals("-1 EV", format.format(-1.0));
        assertEquals("-5/6 EV", format.format(-5/6.0));
        assertEquals("-2/3 EV", format.format(-2/3.0));
        assertEquals("-1/2 EV", format.format(-1/2.0));
        assertEquals("-1/3 EV", format.format(-1/3.0));
        assertEquals("-1/6 EV", format.format(-1/6.0));
        assertEquals("0 EV", format.format(0.0));
        assertEquals("+1/6 EV", format.format(1/6.0));
        assertEquals("+1/3 EV", format.format(1/3.0));
        assertEquals("+1/2 EV", format.format(1/2.0));
        assertEquals("+2/3 EV", format.format(2/3.0));
        assertEquals("+5/6 EV", format.format(5/6.0));
        assertEquals("+1 EV", format.format(1.0));
        assertEquals("+1 1/6 EV", format.format(1 + 1/6.0));
        assertEquals("+1 1/3 EV", format.format(1 + 1/3.0));
        assertEquals("+1 1/2 EV", format.format(1 + 1/2.0));
        assertEquals("+1 2/3 EV", format.format(1 + 2/3.0));
        assertEquals("+1 5/6 EV", format.format(1 + 5/6.0));
      }

    @Test
    public void testFormatWithUnicode() 
      {
        assertEquals("-1 \u215A EV", formatUnicode.format(-1 - 5/6.0));
        assertEquals("-1 \u2154 EV", formatUnicode.format(-1 - 2/3.0));
        assertEquals("-1 \u00bd EV", formatUnicode.format(-1 - 1/2.0));
        assertEquals("-1 \u2153 EV", formatUnicode.format(-1 - 1/3.0));
        assertEquals("-1 \u2159 EV", formatUnicode.format(-1 - 1/6.0));
        assertEquals("-1 EV", formatUnicode.format(-1.0));
        assertEquals("-\u215A EV", formatUnicode.format(-5/6.0));
        assertEquals("-\u2154 EV", formatUnicode.format(-2/3.0));
        assertEquals("-\u00bd EV", formatUnicode.format(-1/2.0));
        assertEquals("-\u2153 EV", formatUnicode.format(-1/3.0));
        assertEquals("-\u2159 EV", formatUnicode.format(-1/6.0));
        assertEquals("0 EV", formatUnicode.format(0.0));
        assertEquals("+\u2159 EV", formatUnicode.format(1/6.0));
        assertEquals("+\u2153 EV", formatUnicode.format(1/3.0));
        assertEquals("+\u00bd EV", formatUnicode.format(1/2.0));
        assertEquals("+\u2154 EV", formatUnicode.format(2/3.0));
        assertEquals("+\u215A EV", formatUnicode.format(5/6.0));
        assertEquals("+1 EV", formatUnicode.format(1.0));
        assertEquals("+1 \u2159 EV", formatUnicode.format(1 + 1/6.0));
        assertEquals("+1 \u2153 EV", formatUnicode.format(1 + 1/3.0));
        assertEquals("+1 \u00bd EV", formatUnicode.format(1 + 1/2.0));
        assertEquals("+1 \u2154 EV", formatUnicode.format(1 + 2/3.0));
        assertEquals("+1 \u215A EV", formatUnicode.format(1 + 5/6.0));
      }
    
    @Test
    public void parse() 
      throws ParseException
      {
        assertEquals(-1 - 5/6.0, format.parse("-1 5/6 EV"));
        assertEquals(-1 - 2/3.0, format.parse("-1 2/3 EV"));
        assertEquals(-1 - 1/2.0, format.parse("-1 1/2 EV"));
        assertEquals(-1 - 1/3.0, format.parse("-1 1/3 EV"));
        assertEquals(-1 - 1/6.0, format.parse("-1 1/6 EV"));
        assertEquals(-1.0,       format.parse("-1 EV"));
        assertEquals(-5/6.0,     format.parse("-5/6 EV"));
        assertEquals(-2/3.0,     format.parse("-2/3 EV"));
        assertEquals(-1/2.0,     format.parse("-1/2 EV"));
        assertEquals(-1/3.0,     format.parse("-1/3 EV"));
        assertEquals(-1/6.0,     format.parse("-1/6 EV"));
        assertEquals(0.0,        format.parse("0 EV"));
        assertEquals(+1/6.0,     format.parse("+1/6 EV"));
        assertEquals(+1/3.0,     format.parse("+1/3 EV"));
        assertEquals(+1/2.0,     format.parse("+1/2 EV"));
        assertEquals(+2/3.0,     format.parse("+2/3 EV"));
        assertEquals(+5/6.0,     format.parse("+5/6 EV"));
        assertEquals(+1.0,       format.parse("+1 EV"));
        assertEquals(+1 + 1/6.0, format.parse("+1 1/6 EV"));
        assertEquals(+1 + 1/3.0, format.parse("+1 1/3 EV"));
        assertEquals(+1 + 1/2.0, format.parse("+1 1/2 EV"));
        assertEquals(+1 + 2/3.0, format.parse("+1 2/3 EV"));
        assertEquals(+1 + 5/6.0, format.parse("+1 5/6 EV"));
      }
  }