/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.text;

import java.text.ParseException;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class EXIFFlashFormatTest 
  {
    private EXIFFlashFormat format;
    
    @Before
    public void setupFixture()
      {
        format = new EXIFFlashFormat();
      }  

    @After
    public void tearDownFixture() 
      {
        format = null;
      }

    @Test
    public void format() 
      {
        assertEquals("did not fire", format.format(0x0000));
        assertEquals("fired", format.format(0x0001));
        assertEquals("strobe not detected", format.format(0x0005));
        assertEquals("strobe detected", format.format(0x0007));
        assertEquals("fired, compulsory", format.format(0x0009));
        assertEquals("fired, compulsory, not detected", format.format(0x000D));
        assertEquals("fired, compulsory, detected", format.format(0x000F));
        assertEquals("did not fire, compulsory", format.format(0x0010));
        assertEquals("did not fire, auto", format.format(0x0018));
        assertEquals("fired, auto", format.format(0x0019));
        assertEquals("fired, auto, not detected", format.format(0x001D));
        assertEquals("fired, auto, detected", format.format(0x001F));
        assertEquals("no flash", format.format(0x0020));
        assertEquals("fired, red-eye", format.format(0x0041));
        assertEquals("fired, red-eye, not detected", format.format(0x0045));
        assertEquals("fired, red-eye, detected", format.format(0x0047));
        assertEquals("fired, compulsory, red-eye", format.format(0x0049));
        assertEquals("fired, compulsory, red-eye, not detected", format.format(0x004D));
        assertEquals("fired, compulsory, red-eye, detected", format.format(0x004F));
        assertEquals("fired, auto, red-eye", format.format(0x0059));
        assertEquals("fired, auto, not detected, red-eye", format.format(0x005D));
        assertEquals("fired, auto, detected, red-eye", format.format(0x005F));
      }

    @Test
    public void parse()
      throws ParseException 
      {
        try
          {
            format.parseObject("xxx");
            fail("UnsupportedOperationException expected");
          }
        catch (UnsupportedOperationException e)
          {
            // ok
          }
      }
  }