/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.text;

import java.text.ParseException;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class ShutterFormatTest 
  {
    private ShutterFormat format;
    
    @Before
    public void setupFixture()
      {
        format = new ShutterFormat();
      }  

    @After
    public void tearDownFixture() 
      {
        format = null;
      }

    @Test
    public void testFormat() 
      {
        assertEquals("60 sec", format.format(60.0));
        assertEquals("30 sec", format.format(30.0));
        assertEquals("15 sec", format.format(15.0));
        assertEquals("8 sec", format.format(8.0));
        assertEquals("4 sec", format.format(4.0));
        assertEquals("2 sec", format.format(2.0));
        assertEquals("1.5 sec", format.format(1.5));
        assertEquals("1 sec", format.format(1.0));
        assertEquals("1/1.3 sec", format.format(76923076.0/100000000.0));
        assertEquals("1/1.25 sec", format.format(8.0 / 10.0));
//        assertEquals("8/10 sec", format.format(8.0 / 10.0));
        assertEquals("1/2 sec", format.format(1 / 2.0));
        assertEquals("1/4 sec", format.format(1 / 4.0));
        assertEquals("1/8 sec", format.format(1 / 8.0));
        assertEquals("1/16 sec", format.format(1 / 16.0));
        assertEquals("1/80 sec", format.format(1 / 80.0));
        assertEquals("1/125 sec", format.format(1 / 125.0));
        assertEquals("1/160 sec", format.format(1 / 160.0));
        assertEquals("1/250 sec", format.format(1 / 250.0));
        assertEquals("1/320 sec", format.format(1 / 320.0));
        assertEquals("1/500 sec", format.format(1 / 500.0));
      }

    @Test
    public void testParse() 
      throws ParseException 
      {
        assertEquals(60.0, format.parse("60 sec"));
        assertEquals(30.0, format.parse("30 sec"));
        assertEquals(15.0, format.parse("15 sec"));
        assertEquals(8.0, format.parse("8 sec"));
        assertEquals(4.0, format.parse("4 sec"));
        assertEquals(2.0, format.parse("2 sec"));
        assertEquals(1.0, format.parse("1 sec"));
        assertEquals(1/2.0, format.parse("1/2 sec"));
        assertEquals(1/4.0, format.parse("1/4 sec"));
        assertEquals(1/8.0, format.parse("1/8 sec"));
        assertEquals(1/16.0, format.parse("1/16 sec"));
        assertEquals(1/80.0, format.parse("1/80 sec"));
        assertEquals(1/125.0, format.parse("1/125 sec"));
        assertEquals(1/160.0, format.parse("1/160 sec"));
        assertEquals(1/250.0, format.parse("1/250 sec"));
        assertEquals(1/320.0, format.parse("1/320 sec"));
        assertEquals(1/500.0, format.parse("1/500 sec"));
      }
  }